# pyBioTools v0.2.6

[![GitHub license](https://img.shields.io/github/license/a-slide/pyBioTools.svg)](https://github.com/a-slide/pyBioTools/blob/master/LICENSE)
[![Language](https://img.shields.io/badge/Language-Python3-yellow.svg)](https://www.python.org/)
[![DOI](https://zenodo.org/badge/111435767.svg)](https://zenodo.org/badge/latestdoi/111435767)
[![Build Status](https://travis-ci.com/a-slide/pyBioTools.svg?branch=master)](https://travis-ci.com/a-slide/pyBioTools)

[![PyPI version](https://badge.fury.io/py/pyBioTools.svg)](https://badge.fury.io/py/pyBioTools)
[![PyPI downloads](https://pepy.tech/badge/pyBioTools)](https://pepy.tech/project/pyBioTools)
[![Anaconda version](https://anaconda.org/aleg/pybiotools/badges/version.svg)](https://anaconda.org/aleg/pybiotools)
[![Anaconda downloads](https://anaconda.org/aleg/pybiotools/badges/downloads.svg)](https://anaconda.org/aleg/pybiotools)

---

**pyBioTools is a collection of python tools to manipulate biological sequences**

Full documentation is available at https://adrienleger.com/pyBioTools/

## Disclaimer

Please be aware that pyBioTools is a research package that is still under development.

It was tested under Linux Ubuntu 16.04 and in an HPC environment running under Red Hat Enterprise 7.1.

Thank you

---

## Classifiers

* Development Status :: 3 - Alpha
* Intended Audience :: Science/Research
* Topic :: Scientific/Engineering :: Bio-Informatics
* License :: OSI Approved :: GNU General Public License v3 (GPLv3)
* Programming Language :: Python :: 3

## citation

Adrien Leger. a-slide/pyBioTools. Zenodo. http://doi.org/10.5281/zenodo.3235625

## licence

GPLv3 (https://www.gnu.org/licenses/gpl-3.0.en.html)

Copyright © 2020 Adrien Leger

## Authors

* Adrien Leger / aleg@ebi.ac.uk / https://adrienleger.com
